'use strict';

var react = require('react');
var propTypes = require('prop-types');

function _toConsumableArray(arr) {
  return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _nonIterableSpread();
}

function _arrayWithoutHoles(arr) {
  if (Array.isArray(arr)) {
    for (var i = 0, arr2 = new Array(arr.length); i < arr.length; i++) arr2[i] = arr[i];

    return arr2;
  }
}

function _iterableToArray(iter) {
  if (Symbol.iterator in Object(iter) || Object.prototype.toString.call(iter) === "[object Arguments]") return Array.from(iter);
}

function _nonIterableSpread() {
  throw new TypeError("Invalid attempt to spread non-iterable instance");
}

var createElement = function createElement(fonts) {
  var families = fonts.reduce(function (accumulator, font) {
    var family = font.name.replace(' ', '+');
    var weight = font.weight && ":".concat(font.weight.join(',')) || '';
    return [].concat(_toConsumableArray(accumulator), ["".concat(family).concat(weight)]);
  }, []).join('|');
  var link = document.createElement('link');
  link.rel = 'stylesheet';
  link.href = "https://fonts.googleapis.com/css?family=".concat(families);
  return link;
};

var ReactFontLoader = function ReactFontLoader(_ref) {
  var fonts = _ref.fonts;
  react.useEffect(function () {
    var element = createElement(fonts);
    document.head.appendChild(element);
    return function () {
      return document.head.removeChild(element);
    };
  }, []);
  return null;
};

ReactFontLoader.propTypes = {
  fonts: propTypes.arrayOf(propTypes.shape({
    name: propTypes.string.isRequired,
    weights: propTypes.arrayOf(propTypes.oneOfType([propTypes.string, propTypes.number]))
  })).isRequired
};

module.exports = ReactFontLoader;
